class RequiredFieldException(Exception):
    pass


class Rule(object):

    def __init__(self, **kwargs):
        self.required = kwargs.get('required', False)


class Serialiser(object):

    fields = []
    validation = {}
    validated = False

    def validate(self):
        for field in self.fields:
            field_data = getattr(self, field, None)

            if field in self.validation:
                for rule in self.validation.get(field):

                    # Required
                    if rule.required and (field_data is None or field_data == ''):
                        raise RequiredFieldException("`{field}` is required and must not be null or blank.")

        self.validated = True
        return True



from secure import SecureHeaders

secure_headers = SecureHeaders()


def setup_middleware(app):
    @app.middleware('response')
    async def set_secure_headers(request, response):
        secure_headers.sanic(response)




from hashlib import blake2b


def hash_secret(value):
    hashed_value = blake2b(digest_size=32)
    hashed_value.update(value.encode())
    return hashed_value.hexdigest()


def verify_hash(hash, value):
    return hash_secret(value) == hash



import setuptools
with open("README.md", "r") as fh:
    long_description = fh.read()
setuptools.setup(
     name='cm_service_library',
     version='0.0.5',
     author="Trent Murray",
     author_email="trent@cloudmicro.io",
     description="Just another module library",
     long_description=long_description,
     long_description_content_type="text/markdown",
     url="https://gitlab.com/cloudmicro/pypi/service_library",
     packages=setuptools.find_packages(),
     classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
     install_requires=[
        'secure',
    ]
 )
